package calendar

import (
	"encoding/json"
	"errors"
	"path/filepath"
	"spaceofcheng/services/controllers"
	"spaceofcheng/services/models"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service/calendar"
	"spaceofcheng/services/utils"
	"strings"

	"github.com/astaxie/beego"
)

// CaseController 信息
type CalendarController struct {
	dao *calendar.CalendarServ
	controllers.BaseController
}

// Constructor 初始化 Controller
// @Title Constructor
// @Description 初始化 Controller, 系统自动调用
func (c *CalendarController) Constructor() {
	c.dao = calendar.NewCalendarServ(c.Context)
}

type CalendarImg struct {
	CalendarImg string
	CustomerImg string
	ImgName     string
	Sort        int
}
type Calendar struct {
	ModelName string
	Email     string
	CaseId    string
	Imgs      []CalendarImg
}

func (c *CalendarController) GetCalendarList() {
	caseIDs := c.GetString("caseid")
	if caseIDs == "" {
		cases := c.Context.Get("cases").([]model.SysUserCase)
		caseIDs = c.GetCaseIDs(cases)
	}
	name := c.GetString("name")
	phone := c.GetString("phone")
	makeStatus := c.GetString("makeStatus")
	page, _ := c.GetInt("page")
	pageSize, _ := c.GetInt("pagesize")
	list, err := c.dao.GetCalendarList(caseIDs, name, phone, makeStatus, page, pageSize)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(list)
}

func (c *CalendarController) ChangeMakeStaus() {
	calendarIds := c.GetString(":calendarIds")
	calendar := strings.Split(calendarIds, ",")
	beego.Error(calendar)
	for i := 0; i < len(calendar); i++ {
		err := c.dao.ChangeMakeStaus(calendar[i])
		if err != nil {
			c.ResponseError(err)
		}
	}
	c.ResponseJSON("修改成功")
}

func (c *CalendarController) DownloadImg() {
	calendarId := c.GetString(":calendarId")
	imgType := c.GetString(":imgType")
	list, err := c.dao.GetCalendarImgs(calendarId)
	if err != nil {
		c.ResponseError(err)
	}
	customerCalendar, err := c.dao.GetCalendarFrontDetailById(calendarId)
	if err != nil {
		c.ResponseError(err)
	}
	var files []utils.NetFile
	var zf string
	if imgType == "user" {
		for i := 0; i < len(list); i++ {
			if list[i].CustomerImg != "" {
				ext := filepath.Ext(list[i].ImgName)
				var file = utils.NetFile{
					URI:  list[i].CustomerImg,
					Name: list[i].ImgName + ext,
				}
				if file.URI != "" {
					files = append(files, file)
				}

			}

		}
		zf = customerCalendar.Email + "照片.zip"
	} else {
		for i := 0; i < len(list); i++ {
			if list[i].CalendarImg != "" {
				ext := filepath.Ext(list[i].ImgName)
				var file = utils.NetFile{
					URI:  list[i].CalendarImg,
					Name: list[i].ImgName + ext,
				}
				if file.URI != "" {
					files = append(files, file)
				}
			}

		}
		zf = customerCalendar.Email + "台历.zip"
	}
	if len(files) <= 0 {
		c.ResponseError(errors.New("图片为空"))
	}
	c.SaveNetFilesToZip(files, zf)
}
func (c *CalendarController) GetCalendarListFront() {
	cust := c.Context.Get("customer").(model.TaCustomer)
	page, _ := c.GetInt("page")
	pageSize, _ := c.GetInt("pagesize")
	list, err := c.dao.GetCalendarListFront(cust.CustomerId, page, pageSize)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(list)
}

func (c *CalendarController) GetCalendarListExcel() {
	caseIDs := c.GetString("caseid")
	if caseIDs == "" {
		cases := c.Context.Get("cases").([]model.SysUserCase)
		caseIDs = c.GetCaseIDs(cases)
	}
	name := c.GetString("name")
	phone := c.GetString("phone")
	list, err := c.dao.GetCalendarListExcel(caseIDs, name, phone)
	if err != nil {
		c.ResponseError(err)
	}
	excel, err := utils.NewTinyXLSXEngine()
	if err != nil {
		utils.LogError("初始化Excel服务失败: " + err.Error())
		c.ResponseError(errors.New("初始化Excel服务失败"))
	}
	excel.SetCell(excel.InsertRow(), []string{
		"模板",
		"姓名",
		"昵称",
		"手机号",
		"邮箱",
		"定制时间",
		"状态",
	})
	for _, item := range list {
		row := excel.InsertRow()
		makeStatus := ""
		switch item.MakeStatus {
		case models.CALENDAR_MAKING:
			makeStatus = "制作中"
			break
		case models.CALENDAR_FINISH:
			makeStatus = "制作完成"
			break
		}
		excel.SetCell(row, []string{
			item.ModelName,
			item.Name,
			item.CustomerName,
			item.Phone,
			item.Email,
			item.CreateDate.Format("2006-01-02 15:04:05"),
			makeStatus,
		})
	}
	c.SaveToExcel("日历定制记录.xlsx", excel)
}
func (c *CalendarController) GetCalendarFrontDetailById() {
	calendarId := c.GetString(":calendarId")
	detail, err := c.dao.GetCalendarFrontDetailById(calendarId)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(detail)
}

func (c *CalendarController) AddCalendar() {
	cust := c.Context.Get("customer").(model.TaCustomer)
	org := c.Context.Get("org").(model.SysOrg)
	calendarJson := c.GetString("Calendar")
	calendar := Calendar{}
	err := json.Unmarshal([]byte(calendarJson), &calendar)
	if err != nil {
		c.ResponseError(err)
	}
	utils.LogInfo("↓↓↓↓_________________________↓↓↓↓parse calendar↓↓↓↓___________________↓↓↓↓")
	utils.LogInfo(calendar)
	receicveCalendar := model.TaCustomerCalendar{
		CaseId:    calendar.CaseId,
		ModelName: calendar.ModelName,
		Email:     calendar.Email,
	}
	receiveImgs := calendar.Imgs
	receicveCalendar.CustomerId = cust.CustomerId
	receicveCalendar.OrgId = org.OrgId
	customerCalendar, err := c.dao.AddCalendar(receicveCalendar)
	if err != nil {
		c.ResponseError(err)
	}
	var calendarImgs []model.TaCalendarImg
	for i := 0; i < len(receiveImgs); i++ {
		var calendarImg = model.TaCalendarImg{
			CalendarImg: receiveImgs[i].CalendarImg,
			CustomerImg: receiveImgs[i].CustomerImg,
			ImgName:     receiveImgs[i].ImgName,
			Sort:        receiveImgs[i].Sort,
		}
		calendarImgs = append(calendarImgs, calendarImg)
	}
	utils.LogInfo("↓↓↓↓_________________________↓↓↓↓calendar imgs↓↓↓↓___________________↓↓↓↓")
	utils.LogInfo(calendarImgs)
	err = c.dao.AddCalendarImg(calendarImgs, customerCalendar.CustomerCalendarId)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON("添加成功")

}
func (c *CalendarController) IsCustomerAttend() {
	cust := c.Context.Get("customer").(model.TaCustomer)
	flag, err := c.dao.IsCustomerAttend(cust.CustomerId)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(flag)
}
