package calendar

import (
	"spaceofcheng/services/models"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
	"strconv"
	"strings"
	"time"

	"github.com/go-xorm/xorm"
)

// CalendarDAO 当前数据库操作对象
type CalendarDAO struct {
	ctx *utils.Context
	db  *xorm.Session
}

// NewCalendarDAO New Inst
func NewCalendarDAO(ctx *utils.Context) *CalendarDAO {
	return &CalendarDAO{
		ctx: ctx,
		db:  ctx.DB,
	}
}

type CalendarList struct {
	model.TaCustomerCalendar `xorm:"extends"`
	Name                     string
	Phone                    string
	CustomerName             string
}

type CalendarFrontDetail struct {
	model.TaCustomerCalendar `xorm:"extends"`
	CaseName                 string
	Imgs                     []model.TaCalendarImg
}

type CalendarListFront struct {
	model.TaCustomerCalendar `xorm:"extends"`
	CaseName                 string
}

// GetCalendarList 后台日历列表
func (m *CalendarDAO) GetCalendarList(caseid, name, phone, makeStatus string, page, pageSize int) ([]CalendarList, error) {
	var calendar []CalendarList
	sql := `SELECT
	a.*,
	b.NAME,
	b.phone,
	b.customer_name 
FROM
	ta_customer_calendar a
	INNER JOIN ta_customer b ON a.customer_id = b.customer_id 
WHERE
	a.STATUS > ` + strconv.Itoa(models.STATUS_DEL) + `
	and a.case_id in('` + strings.Replace(caseid, ",", "','", -1) + `')`
	if name != "" {
		sql += ` and b.name like '%` + name + `%'`
	}
	if phone != "" {
		sql += ` and b.phone like '%` + phone + `%'`
	}
	if makeStatus != "" {
		sql += `and a.make_status = '` + makeStatus + `'`
	}
	sql += ` order by a.create_date desc limit ` + strconv.Itoa((page-1)*pageSize) + `, ` + strconv.Itoa(pageSize)
	err := m.db.Sql(sql).Find(&calendar)
	return calendar, err
}

// GetCalendarListCount 后台日历列表数量
func (m *CalendarDAO) GetCalendarListCount(caseid, name, phone, makeStatus string) (int, error) {
	var calendar []CalendarList
	sql := `SELECT
	a.*,
	b.NAME,
	b.phone,
	b.customer_name 
FROM
	ta_customer_calendar a
	INNER JOIN ta_customer b ON a.customer_id = b.customer_id 
WHERE
	a.STATUS > ` + strconv.Itoa(models.STATUS_DEL) + `
	and a.case_id in('` + strings.Replace(caseid, ",", "','", -1) + `')`
	if name != "" {
		sql += ` and b.name like '%` + name + `%'`
	}
	if phone != "" {
		sql += ` and b.phone like '%` + phone + `%'`
	}
	if makeStatus != "" {
		sql += `and a.make_status = '` + makeStatus + `'`
	}
	err := m.db.Sql(sql).Find(&calendar)
	return len(calendar), err
}

// GetCalendarListFront 前台活动我的日历列表
func (m *CalendarDAO) GetCalendarListFront(customerId string, page, pageSize int) ([]CalendarListFront, error) {
	var calendar []CalendarListFront
	sql := `SELECT
	a.*,
	b.case_name 
FROM
	ta_customer_calendar a
	INNER JOIN sys_case b ON a.case_id = b.case_id 
WHERE
	customer_id = '` + customerId + `'
	and a.STATUS > ` + strconv.Itoa(models.STATUS_DEL)
	sql += ` order by a.create_date desc limit ` + strconv.Itoa((page-1)*pageSize) + `, ` + strconv.Itoa(pageSize)
	err := m.db.Sql(sql).Find(&calendar)
	return calendar, err
}

// GetCalendarListFrontCount 前台活动我的日历列表
func (m *CalendarDAO) GetCalendarListFrontCount(customerId string) (int, error) {
	var calendar []CalendarListFront
	sql := `SELECT
	a.*,
	b.case_name 
FROM
	ta_customer_calendar a
	INNER JOIN sys_case b ON a.case_id = b.case_id 
WHERE
	customer_id = '` + customerId + `'
	and a.STATUS > ` + strconv.Itoa(models.STATUS_DEL)
	err := m.db.Sql(sql).Find(&calendar)
	return len(calendar), err
}

// GetCalendarFrontDetailById 获取日历活动详情
func (m *CalendarDAO) GetCalendarFrontDetailById(calendarId string) ([]CalendarFrontDetail, error) {
	var calendar []CalendarFrontDetail
	sql := `SELECT
	a.*,
	b.case_name 
FROM
	ta_customer_calendar a
	INNER JOIN sys_case b ON a.case_id = b.case_id 
WHERE
	customer_calendar_id = '` + calendarId + `'`
	err := m.db.Sql(sql).Find(&calendar)
	return calendar, err
}

// GetCalendarFrontImgDetailById 获取日历详情图片
func (m *CalendarDAO) GetCalendarFrontImgDetailById(calendarId string) ([]model.TaCalendarImg, error) {
	var imgs []model.TaCalendarImg
	sql := `SELECT
	* 
FROM
	ta_calendar_img 
WHERE
	customer_calendar_id = '` + calendarId + `'
	order by sort asc`
	err := m.db.Sql(sql).Find(&imgs)
	return imgs, err
}

// AddCalendar 新增日历活动
func (m *CalendarDAO) AddCalendar(calendar model.TaCustomerCalendar) (*model.TaCustomerCalendar, error) {
	calendar.CustomerCalendarId = utils.GetGUID()
	calendar.CreateDate = time.Now()
	calendar.MakeStatus = models.CALENDAR_MAKING
	calendar.Status = models.STATUS_NORMAL
	_, err := m.db.Insert(calendar)
	return &calendar, err
}

// AddCalendarImg 新增日历活动图片
func (m *CalendarDAO) AddCalendarImg(img model.TaCalendarImg) error {
	img.CalendarImgId = utils.GetGUID()
	img.Status = models.STATUS_NORMAL
	_, err := m.db.Insert(img)
	return err
}

// ChangeMakeStaus 制作完成
func (m *CalendarDAO) ChangeMakeStaus(calendarId string) error {
	var calendar = model.TaCustomerCalendar{
		CustomerCalendarId: calendarId,
		MakeStatus:         models.CALENDAR_FINISH,
	}
	var cols = []string{
		"make_status",
	}
	_, err := m.db.Cols(cols...).Where("customer_calendar_id = ?", calendar.CustomerCalendarId).Update(calendar)
	return err
}

// GetCalendarList 后台日历列表Excel导出
func (m *CalendarDAO) GetCalendarListExcel(caseid, name, phone string) ([]CalendarList, error) {
	var calendar []CalendarList
	sql := `SELECT
	a.*,
	b.NAME,
	b.phone,
	b.customer_name 
FROM
	ta_customer_calendar a
	INNER JOIN ta_customer b ON a.customer_id = b.customer_id 
WHERE
	a.STATUS > ` + strconv.Itoa(models.STATUS_DEL) + `
	and a.case_id in('` + strings.Replace(caseid, ",", "','", -1) + `')`
	if name != "" {
		sql += ` and b.name like '%` + name + `%'`
	}
	if phone != "" {
		sql += ` and b.phone like '%` + phone + `%'`
	}
	sql += ` order by a.create_date desc `
	err := m.db.Sql(sql).Find(&calendar)
	return calendar, err
}

func (m *CalendarDAO) IsCustomerAttend(customerId string) (bool, error) {
	flag, err := m.db.Exist(&model.TaCustomerCalendar{CustomerId: customerId})
	return flag, err
}
